.. include:: ../../README.rst

.. ========
.. Contents
.. ========

.. toctree::
   :maxdepth: 2
   :hidden:	      

   installation
   philosophy
   usage
   contributing
   api
   changelog
   authors


